EMAIL = 'jorge.cardoso.pt@gmail.com'
USER_ID = '79cc4a8a-c1ff-4852-9486-62fd8e618623'
PASSWORD = 'ginrom-xUrfib-2sumfa'
